==> freecad_0.17%2Bdfsg1.orig.tar.gz: FreeCAD-0.17/src/Mod/Tux/Resources/translations/Tux_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="tr" sourcelanguage="en">
  <context>
    <name>NavigationIndicator</name>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="62"/>
      <source>Select</source>
      <translation>Seç</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="63"/>
      <source>Zoom</source>
      <translation>Yakınlaştır</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="64"/>
      <source>Rotate</source>
      <translation>Döndür</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="65"/>
      <source>Pan</source>
      <translation>Yassılaştır</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="66"/>
      <source>Tilt</source>
      <translation>Eğimi ayarla</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="67"/>
      <source>Navigation style</source>
      <translation>Navigasyon stili</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="68"/>
      <source>Page Up or Page Down key.</source>
      <translation>Sayfa Yukarı ve Sayfa Aşağı Tuşu.</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="69"/>
      <source>Rotation focus</source>
      <translation>Döndürme odaklaması</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="70"/>
      <source>Middle mouse button or key H.</source>
      <translation>Orta fare tuşu ya da düğmesi.</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="71"/>
      <source>Middle mouse button.</source>
      <translation>Orta fare tuşu.</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="74"/>
      <source>Navigation style not recognized.</source>
      <translation>Navigasyon stili tanınmıyor.</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="291"/>
      <source>Settings</source>
      <translation>Ayarlar</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="292"/>
      <source>Orbit style</source>
      <translation>Yörünge stili</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="293"/>
      <source>Compact</source>
      <translation>Sıkılaştır</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="294"/>
      <source>Tooltip</source>
      <translation>Ipucu</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="295"/>
      <source>Turntable</source>
      <translation>Döner tabla</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="296"/>
      <source>Trackball</source>
      <translation>Trackball</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="297"/>
      <source>Undefined</source>
      <translation type="unfinished">Undefined</translation>
    </message>
  </context>
</TS>

==> freecad_0.18~pre1%2Bdfsg1.orig.tar.gz: FreeCAD-0.18_pre/src/Mod/Tux/Resources/translations/Tux_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="tr" sourcelanguage="en">
  <context>
    <name>NavigationIndicator</name>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="62"/>
      <source>Select</source>
      <translation>Seç</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="63"/>
      <source>Zoom</source>
      <translation>Yakınlaştır</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="64"/>
      <source>Rotate</source>
      <translation>Döndür</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="65"/>
      <source>Pan</source>
      <translation>Yassılaştır</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="66"/>
      <source>Tilt</source>
      <translation>Eğimi ayarla</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="67"/>
      <source>Navigation style</source>
      <translation>Navigasyon stili</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="68"/>
      <source>Page Up or Page Down key.</source>
      <translation>Sayfa Yukarı veya Sayfa Aşağı Tuşu.</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="69"/>
      <source>Rotation focus</source>
      <translation>Döndürme odaklaması</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="70"/>
      <source>Middle mouse button or key H.</source>
      <translation>Orta fare tuşu ya da düğmesi.</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="71"/>
      <source>Middle mouse button.</source>
      <translation>Fare orta düğmesi.</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="74"/>
      <source>Navigation style not recognized.</source>
      <translation>Navigasyon stili tanınmıyor.</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="291"/>
      <source>Settings</source>
      <translation>Ayarlar</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="292"/>
      <source>Orbit style</source>
      <translation>Yörünge stili</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="293"/>
      <source>Compact</source>
      <translation>Sıkılaştır</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="294"/>
      <source>Tooltip</source>
      <translation>Ipucu</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="295"/>
      <source>Turntable</source>
      <translation>Döner tabla</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="296"/>
      <source>Trackball</source>
      <translation>Trackball</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="297"/>
      <source>Undefined</source>
      <translation type="unfinished">Undefined</translation>
    </message>
  </context>
</TS>
